package
Version:
v0.0.0-...-39cda13
Opens a new window with list of versions in this module.
Published: May 13, 2024
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Data struct {
IpAssignmentPools []IPAssign `json:"ipAssignmentPools"`
}
type IPAssign struct {
IpRangeStart string `json:"ipRangeStart"`
IpRangeEnd string `json:"ipRangeEnd"`
}
type PeerData struct {
PeerID string `json:"id"`
IPAssignments []string `json:"ipAssignments"`
}
type ThePeer struct {
PeerID string `json:"id"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.